#[non_exhaustive]pub enum RocksDbOpenError {
NoBaseDir,
CreateDir(Error),
Lock(DbLockError),
EnvParse {
var: &'static str,
source: ParseIntError,
},
EnvNotPowerOfTwo {
var: &'static str,
},
RocksDb(Error),
}Expand description
Why a RocksDb or RocksDbReadOnly could not be opened.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoBaseDir
The database path has no parent directory to create; only when opening for writing.
CreateDir(Error)
The parent directory of the database could not be created; only when opening for writing.
Lock(DbLockError)
The lock file next to the database could not be opened or locked; only when opening for writing.
EnvParse
A size override in the environment is not a number, or is too large
for a usize.
Fields

source: ParseIntErrorWhy its value could not be parsed.
EnvNotPowerOfTwo
A size override in the environment is not a power of two.
RocksDb(Error)
RocksDB could not open the database.